use strict;
use warnings;

my ($message) = @ARGV;

print "Hello $message";
